# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),

## [Unreleased]

## [0.1.0] - 2021-01-18
### Added
- Prepare the repository, configure the tox and pre-commit tools.
